/*============================
		COLOR Cyan
==============================*/
::selection {
  background: #17a2b8;
}

a, a:focus {
  color: #17a2b8;
}

a:hover, a:active {
  color: #138698;
}

.primary-menu ul.navbar-nav > li:hover > a:not(.btn), .primary-menu ul.navbar-nav > li > a.active:not(.btn) {
  color: #17a2b8;
}
.primary-menu ul.navbar-nav > li.dropdown .dropdown-menu li:hover > a:not(.btn) {
  color: #17a2b8;
}
.primary-menu.navbar-line-under-text ul.navbar-nav > li > a:not(.btn):after {
  border-color: #17a2b8;
}

/*=== Side Navigation ===*/
.idocs-navigation .nav .nav .nav-item .nav-link.active:after, .idocs-navigation.docs-navigation-dark .nav .nav .nav-item .nav-link.active:after {
  border-color: #17a2b8;
}

/* Accordion & Toggle */
.accordion .card-header a:hover.collapsed {
  color: #17a2b8 !important;
}
.accordion:not(.accordion-alternate) .card-header a {
  background-color: #17a2b8;
  color: #fff;
}

/* Nav */
.nav:not(.nav-pills) .nav-item .nav-link.active, .nav:not(.nav-pills) .nav-item .nav-link:hover {
  color: #17a2b8;
}

.nav-tabs .nav-item .nav-link.active {
  color: #0c2f55;
}
.nav-tabs .nav-item .nav-link.active:after {
  background-color: #17a2b8;
}
.nav-tabs .nav-item .nav-link:not(.active):hover {
  color: #17a2b8;
}
.nav-tabs.flex-column .nav-item .nav-link.active {
  color: #17a2b8;
}

.nav-pills .nav-link:not(.active):hover {
  color: #17a2b8;
}

#footer .nav .nav-item .nav-link:focus {
  color: #17a2b8;
}
#footer .nav .nav-link:hover {
  color: #17a2b8;
}
#footer .footer-copyright .nav .nav-link:hover {
  color: #17a2b8;
}

/* Back to Top */
#back-to-top:hover {
  background-color: #17a2b8;
}

/* Extras */
.bg-primary, .badge-primary {
  background-color: #17a2b8 !important;
}

.text-primary, .btn-light, .btn-outline-light:hover, .btn-link, .btn-outline-light:not(:disabled):not(.disabled).active, .btn-outline-light:not(:disabled):not(.disabled):active {
  color: #17a2b8 !important;
}

.btn-link:hover {
  color: #138698 !important;
}

.text-muted {
  color: #8e9a9d !important;
}

.text-light {
  color: #dee3e4 !important;
}

a.bg-primary:focus, a.bg-primary:hover, button.bg-primary:focus, button.bg-primary:hover {
  background-color: #138698 !important;
}

.border-primary {
  border-color: #17a2b8 !important;
}

.btn-primary {
  background-color: #17a2b8;
  border-color: #17a2b8;
}
.btn-primary:hover {
  background-color: #138698;
  border-color: #138698;
}

.btn-primary:not(:disabled):not(.disabled).active, .btn-primary:not(:disabled):not(.disabled):active {
  background-color: #138698;
  border-color: #138698;
}

.btn-primary.focus, .btn-primary:focus {
  background-color: #138698;
  border-color: #138698;
}

.btn-outline-primary, .btn-outline-primary:not(:disabled):not(.disabled).active, .btn-outline-primary:not(:disabled):not(.disabled):active {
  color: #17a2b8;
  border-color: #17a2b8;
}
.btn-outline-primary:hover, .btn-outline-primary:not(:disabled):not(.disabled).active:hover, .btn-outline-primary:not(:disabled):not(.disabled):active:hover {
  background-color: #17a2b8;
  border-color: #17a2b8;
  color: #fff;
}

.progress-bar,
.nav-pills .nav-link.active, .nav-pills .show > .nav-link, .dropdown-item.active, .dropdown-item:active {
  background-color: #17a2b8;
}

.page-item.active .page-link,
.custom-radio .custom-control-input:checked ~ .custom-control-label:before,
.custom-control-input:checked ~ .custom-control-label::before,
.custom-checkbox .custom-control-input:checked ~ .custom-control-label:before,
.custom-control-input:checked ~ .custom-control-label:before {
  background-color: #17a2b8;
  border-color: #17a2b8;
}

.list-group-item.active {
  background-color: #17a2b8;
  border-color: #17a2b8;
}

.page-link {
  color: #17a2b8;
}
.page-link:hover {
  color: #138698;
}
